==> mongodb_5.3.1.orig.tar.gz: mongo-r5.3.1/src/mongo/db/s/sharding_data_transform_metrics_observer.h <==
/**
 *    Copyright (C) 2022-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#pragma once

#include "mongo/db/s/sharding_data_transform_metrics.h"
#include "mongo/util/uuid.h"

namespace mongo {
class ShardingDataTransformMetricsObserverInterface {
public:
    virtual int64_t getRemainingTimeMillis() const = 0;
    virtual int64_t getStartTimestamp() const = 0;
    virtual const UUID& getUuid() const = 0;
};

class ShardingDataTransformMetricsObserver : public ShardingDataTransformMetricsObserverInterface {
public:
    ShardingDataTransformMetricsObserver(ShardingDataTransformInstanceMetrics* metrics);
    int64_t getRemainingTimeMillis() const override;
    int64_t getStartTimestamp() const override;
    const UUID& getUuid() const override;

private:
    ShardingDataTransformInstanceMetrics* _metrics;
};

}  // namespace mongo

==> mongodb_6.1.1.orig.tar.gz: mongo-r6.1.1/src/mongo/db/s/sharding_data_transform_metrics_observer.h <==
/**
 *    Copyright (C) 2022-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#pragma once

#include "mongo/db/s/sharding_data_transform_instance_metrics.h"
#include "mongo/db/s/sharding_data_transform_metrics_observer_interface.h"
#include "mongo/util/uuid.h"

namespace mongo {

class ShardingDataTransformMetricsObserver : public ShardingDataTransformMetricsObserverInterface {
public:
    ShardingDataTransformMetricsObserver(ShardingDataTransformInstanceMetrics* metrics);
    boost::optional<Milliseconds> getHighEstimateRemainingTimeMillis() const override;
    boost::optional<Milliseconds> getLowEstimateRemainingTimeMillis() const override;
    Date_t getStartTimestamp() const override;
    const UUID& getUuid() const override;
    ShardingDataTransformMetrics::Role getRole() const override;

private:
    ShardingDataTransformInstanceMetrics* _metrics;
};

}  // namespace mongo
